@@ -40,12 +40,12 @@
 
 
 
--- INSTALL VERSION: '3.5.3'
+-- INSTALL VERSION: '3.6.0'
 
 BEGIN;
 
 CREATE OR REPLACE FUNCTION postgis_sfcgal_scripts_installed() RETURNS text
-	AS $$ SELECT trim('3.5.3'::text || $rev$ aab5f55 $rev$) AS version $$
+	AS $$ SELECT trim('3.6.0'::text || $rev$ 4c1967d $rev$) AS version $$
 	LANGUAGE 'sql' IMMUTABLE;
 
 -- Availability: 2.1.0
@@ -526,5 +526,110 @@ CREATE OR REPLACE FUNCTION CG_Visibility(polygon geometry, point geometry)
        LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
        COST 100;
 
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_3DBuffer(geom geometry, radius float8, segments integer, buffer_type integer)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_buffer3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 5000;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_StraightSkeletonPartition(geom geometry, auto_orientation boolean)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_straight_skeleton_partition'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 250;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_RotateX(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_x'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_RotateY(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_y'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_RotateZ(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_z'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_Rotate(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_2DRotate(geom geometry, angle float8, cx float8, cy float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_2d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_3DRotate(geom geometry, angle float8, ax float8, ay float8, az float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_Scale(geom geometry, factor float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_scale'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_3DScaleAroundCenter(geom geometry, factorX float8, factorY float8, factorZ float8, centerX float8, centerY float8, centerZ float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_scale_3d_around_center'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_3DScale(geom geometry, factorX float8, factorY float8, factorZ float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_scale_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_Translate(geom geometry, deltaX float8, deltaY float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_translate_2d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_3DTranslate(geom geometry, deltaX float8, deltaY float8, deltaZ float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_translate_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability 3.6.0
+CREATE OR REPLACE FUNCTION CG_Simplify(geom geometry, threshold float8, preserveTopology boolean DEFAULT false )
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_simplify'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
+-- Availability: 3.6.0
+CREATE OR REPLACE FUNCTION CG_3DAlphaWrapping(geom geometry, relative_alpha int, relative_offset int DEFAULT 0)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_alphawrapping_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+
 COMMIT;
 
