@@ -185,7 +185,7 @@ LANGUAGE 'plpgsql' VOLATILE STRICT
 
 
 --
--- UPGRADE SCRIPT TO PostGIS 3.5.3
+-- UPGRADE SCRIPT TO PostGIS 3.6.0
 --
 
 LOAD '$libdir/postgis_sfcgal-3';
@@ -203,13 +203,13 @@ DECLARE
 BEGIN
 
     old_scripts := postgis_scripts_installed();
-    new_scripts := '3.5.3';
+    new_scripts := '3.6.0';
 
     BEGIN
         new_ver_int := pg_catalog.string_to_array(
             pg_catalog.regexp_replace(
                 new_scripts,
-                '[^\d.].*',
+                E'[^\\d.].*',
                 ''
             ),
             '.'
@@ -222,7 +222,7 @@ BEGIN
         old_ver_int := pg_catalog.string_to_array(
             pg_catalog.regexp_replace(
                 old_scripts,
-                '[^\d.].*',
+                E'[^\\d.].*',
                 ''
             ),
             '.'
@@ -253,7 +253,7 @@ BEGIN
     END IF;
 
     WITH versions AS (
-      SELECT '3.5.3'::text as upgraded,
+      SELECT '3.6.0'::text as upgraded,
       postgis_scripts_installed() as installed
     ) SELECT
       upgraded as scripts_upgraded,
@@ -298,8 +298,9 @@ END
 $$
 LANGUAGE 'plpgsql';
 
+
 CREATE OR REPLACE FUNCTION postgis_sfcgal_scripts_installed() RETURNS text
-	AS $$ SELECT trim('3.5.3'::text || $rev$ aab5f55 $rev$) AS version $$
+	AS $$ SELECT trim('3.6.0'::text || $rev$ 4c1967d $rev$) AS version $$
 	LANGUAGE 'sql' IMMUTABLE;
 CREATE OR REPLACE FUNCTION postgis_sfcgal_version() RETURNS text
         AS '$libdir/postgis_sfcgal-3'
@@ -699,6 +700,81 @@ CREATE OR REPLACE FUNCTION CG_Visibility(polygon geometry, point geometry)
        AS '$libdir/postgis_sfcgal-3', 'sfcgal_visibility_point'
        LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
        COST 100;
+CREATE OR REPLACE FUNCTION CG_3DBuffer(geom geometry, radius float8, segments integer, buffer_type integer)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_buffer3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 5000;
+CREATE OR REPLACE FUNCTION CG_StraightSkeletonPartition(geom geometry, auto_orientation boolean)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_straight_skeleton_partition'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 250;
+CREATE OR REPLACE FUNCTION CG_RotateX(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_x'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_RotateY(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_y'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_RotateZ(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_z'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_Rotate(geom geometry, angle float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_2DRotate(geom geometry, angle float8, cx float8, cy float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_2d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_3DRotate(geom geometry, angle float8, ax float8, ay float8, az float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_rotate_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_Scale(geom geometry, factor float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_scale'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_3DScaleAroundCenter(geom geometry, factorX float8, factorY float8, factorZ float8, centerX float8, centerY float8, centerZ float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_scale_3d_around_center'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_3DScale(geom geometry, factorX float8, factorY float8, factorZ float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_scale_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_Translate(geom geometry, deltaX float8, deltaY float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_translate_2d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_3DTranslate(geom geometry, deltaX float8, deltaY float8, deltaZ float8)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_translate_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_Simplify(geom geometry, threshold float8, preserveTopology boolean DEFAULT false )
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_simplify'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
+CREATE OR REPLACE FUNCTION CG_3DAlphaWrapping(geom geometry, relative_alpha int, relative_offset int DEFAULT 0)
+RETURNS geometry
+AS '$libdir/postgis_sfcgal-3', 'sfcgal_alphawrapping_3d'
+LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE
+COST 50;
 DROP FUNCTION _postgis_upgrade_info();
 -- PostGIS - Spatial Types for PostgreSQL
 -- http://postgis.net
